@@ -1,4 +1,4 @@
-// Copyright (C) 2016 Stanislav Kovalevsky
+// Copyright (C) 2016-2018 Stanislav Kovalevsky
 //
 // This file is part of QuantTools.
 //
@@ -26,7 +26,7 @@ enum class ExecutionType: int { TRADE, BBO };
 
 enum class OrderSide: int { BUY, SELL };
 
-enum class OrderType: int { MARKET, LIMIT };
+enum class OrderType: int { MARKET, LIMIT, STOP, TRAIL };
 
 enum class OrderState: int {
   NEW,        // created
@@ -58,6 +58,7 @@ class Order {
     OrderSide side;
     OrderType type;
     double price;
+    double trail;
     double priceExecuted;
     int idTrade;
 
@@ -80,6 +81,8 @@ class Order {
     double timeProcessed;
 
     bool allowLimitToHitMarket;
+    bool allowExactStop;
+    bool isStopActivated;
 
     double priceExchangeExecuted;
 
@@ -141,7 +144,7 @@ class Order {
       }
       if( stateExchange == OrderStateExchange::REGISTERED ) {
         // market order executed on same tick as registerred
-        if( type == OrderType::MARKET ) {
+        if( type == OrderType::MARKET or isStopActivated ) {
 
           if( executionType == ExecutionType::TRADE and not tick.system ) {
 
@@ -156,6 +159,25 @@ class Order {
 
           }
 
+        }
+        // stop order
+        if( type == OrderType::STOP or type == OrderType::TRAIL ) {
+
+          if( type == OrderType::TRAIL ) {
+
+            if( side == OrderSide::BUY  ) price = std::min( price, tick.price * ( 1. + trail ) );
+            if( side == OrderSide::SELL ) price = std::max( price, tick.price * ( 1. - trail ) );
+
+          }
+
+          // isStopActivated checked first and if true next tick order is executed as market order
+          if( executionType == ExecutionType::TRADE and not tick.system ) {
+            isStopActivated = ( side == OrderSide::BUY and tick.price > price ) or ( side == OrderSide::SELL and tick.price < price );
+          }
+          if( executionType == ExecutionType::BBO ) {
+            isStopActivated = ( side == OrderSide::BUY and ask >= price ) or ( side == OrderSide::SELL and bid <= price );
+          }
+
         }
         // limit order
         if( type == OrderType::LIMIT ) {
@@ -175,8 +197,6 @@ class Order {
               priceExchangeExecuted = price;
 
             }
-
-
           }
 
         }
@@ -196,6 +216,11 @@ class Order {
             }
 
           }
+          if( allowExactStop and ( type == OrderType::STOP or type == OrderType::TRAIL ) ) {
+
+            priceExchangeExecuted = price;
+
+          }
 
         }
 
@@ -260,7 +285,7 @@ class Order {
 
     Order( Order& order ) {
 
-      Order( order.side, order.type, order.price, order.comment, order.idTrade );
+      Order( order.side, order.type, order.price, order.comment, order.idTrade, order.trail );
       onExecuted     = order.onExecuted    ;
       onCancelled    = order.onCancelled   ;
       onRegistered   = order.onRegistered  ;
@@ -268,11 +293,12 @@ class Order {
 
     }
 
-    Order( OrderSide side, OrderType type, double price, std::string comment, int idTrade = NA_INTEGER ):
+    Order( OrderSide side, OrderType type, double price, std::string comment, int idTrade = NA_INTEGER, double trail = 0 ):
 
-      side   ( side ),
-      type   ( type ),
-      price  ( price ),
+      side   ( side    ),
+      type   ( type    ),
+      price  ( price   ),
+      trail  ( trail   ),
       idTrade( idTrade ),
       comment( comment )
 
@@ -295,6 +321,8 @@ class Order {
       state                  = OrderState::NEW;
       stateExchange          = OrderStateExchange::WAIT;
 
+      isStopActivated        = false;
+
     };
 
     void Cancel() {
